Skip to contents

Fetches the official profile for the Delta Sharing open-datasets server and returns it as a parsed list. The profile is public, but fetching it requires an internet connection.

Usage

demo_profile()

Value

A parsed Delta Sharing profile list.

Examples

if (FALSE) { # interactive()
profile <- demo_profile()
names(profile)
}